/v1/projects/{project_id}/virtualbox/vms/{vm_id}/suspend — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »

# /v1/projects/{project_id}/virtualbox/vms/{vm_id}/suspend

Contents

- /v1/projects/{project_id}/virtualbox/vms/{vm_id}/suspend
  - POST /v1/projects/{project_id}/virtualbox/vms/{vm_id}/suspend
    - Parameters
    - Response status codes
    - Sample session

## POST /v1/projects/{project_id}/virtualbox/vms/{vm_id}/suspend

Suspend a VirtualBox VM instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance suspended

### Sample session

    curl -i -X POST 'http://localhost:8000/projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms/4d16597f-fa75-430a-9b94-faf7f93bb0a3/suspend' -d '{}'

    POST /projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms/4d16597f-fa75-430a-9b94-faf7f93bb0a3/suspend HTTP/1.1
    {}

    HTTP/1.1 204
    CONNECTION: keep-alive
    CONTENT-LENGTH: 0
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/virtualbox/vms/{vm_id}/suspend

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »